==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/filedesc/translations/filedesc_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.0">
<context>
    <name>@default</name>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="4"/>
        <source>Status</source>
        <translation>Stato</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="7"/>
        <location filename="../.configuration-ui-translations.cpp" line="10"/>
        <source>FileDesc</source>
        <translation>FileDesc</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="13"/>
        <source>File with description to synchronize</source>
        <translation>File con la descrizione da sincronizzare</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="15"/>
        <source>Enter here a file, which will contain descriptions to refresh by module.</source>
        <translation>Inserisci qui il un file che dovrà contenere le descrizioni aggiornate dal modulo</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="18"/>
        <source>Force status to be &apos;with description&apos;</source>
        <translation>Forza lo stato a diventare &quot;Con Descrizione&quot;</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="20"/>
        <source>If you choose status without description, module will set it automatically to similar but with description</source>
        <translation>Se scegli uno stato senza descrizione, il modulo sarà settato automaticamente ad uno simile ma con la descrizione</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="23"/>
        <source>Allow other descriptions</source>
        <translation>Consenti altre descrizioni</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="25"/>
        <source>Allows you to set some custom description manualy, until file contents doesn&apos;t change</source>
        <translation>Consenti a te stesso di settare diverse descrizioni personalizzate, manualmente, finché il contenuto del file non sarà cambiato</translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/filedesc/translations/filedesc_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Stato</translation>
    </message>
    <message>
        <source>FileDesc</source>
        <translation>FileDesc</translation>
    </message>
    <message>
        <source>File with description to synchronize</source>
        <translation>File con la descrizione da sincronizzare</translation>
    </message>
    <message>
        <source>Enter here a file, which will contain descriptions to refresh by module.</source>
        <translation>Inserisci qui il un file che dovrà contenere le descrizioni aggiornate dal modulo</translation>
    </message>
    <message>
        <source>Force status to be &apos;with description&apos;</source>
        <translation>Forza lo stato a diventare &quot;Con Descrizione&quot;</translation>
    </message>
    <message>
        <source>If you choose status without description, module will set it automatically to similar but with description</source>
        <translation>Se scegli uno stato senza descrizione, il modulo sarà settato automaticamente ad uno simile ma con la descrizione</translation>
    </message>
    <message>
        <source>Allow other descriptions</source>
        <translation>Consenti altre descrizioni</translation>
    </message>
    <message>
        <source>Allows you to set some custom description manualy, until file contents does not change</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
